@@ -62,17 +62,20 @@ def parse_args():
         help="Reinstall payloads(default False)",
     )
     parser.add_argument(
-        "command", choices=["get-devices", "get-details", "install", "refresh"], help="What to do"
+        "command",
+        choices=["get-devices", "get-details", "install", "refresh"],
+        help="What to do",
     )
     parser.add_argument('cab', nargs='?', help='CAB file')
     parser.add_argument('deviceid', nargs='?', help='DeviceID to operate on(optional)')
     args = parser.parse_args()
     return args
 
+
 def refresh(client):
     """Uses fwupd client to refresh metadata"""
     remotes = client.get_remotes()
-    client.set_user_agent_for_package("simple_client", "1.5.3")
+    client.set_user_agent_for_package("simple_client", "1.5.7")
     for remote in remotes:
         if not remote.get_enabled():
             continue
@@ -80,6 +83,7 @@ def refresh(client):
             continue
         client.refresh_remote(remote)
 
+
 def get_devices(client):
     """Use fwupd client to fetch devices"""
     devices = client.get_devices()
